@@ -6,8 +6,7 @@ from importlib import import_module
 
 import click
 
-from celery.bin.base import (CeleryCommand, CeleryOption,
-                             handle_preload_options)
+from celery.bin.base import CeleryCommand, CeleryOption, handle_preload_options
 
 
 def _invoke_fallback_shell(locals):
@@ -80,7 +79,9 @@ def _invoke_default_shell(locals):
         _invoke_ipython_shell(locals)
 
 
-@click.command(cls=CeleryCommand)
+@click.command(cls=CeleryCommand, context_settings={
+    'allow_extra_args': True
+})
 @click.option('-I',
               '--ipython',
               is_flag=True,
@@ -118,7 +119,7 @@ def _invoke_default_shell(locals):
 @handle_preload_options
 def shell(ctx, ipython=False, bpython=False,
           python=False, without_tasks=False, eventlet=False,
-          gevent=False):
+          gevent=False, **kwargs):
     """Start shell session with convenient access to celery symbols.
 
     The following symbols will be added to the main globals:
