@@ -46,7 +46,36 @@ class Tasks(bootsteps.StartStopStep):
                 prefetch_count=prefetch_count,
                 apply_global=qos_global,
             )
-        c.qos = QoS(set_prefetch_count, c.initial_prefetch_count)
+        eta_task_limit = c.app.conf.worker_eta_task_limit
+        c.qos = QoS(
+            set_prefetch_count, c.initial_prefetch_count, max_prefetch=eta_task_limit
+        )
+
+        if c.app.conf.worker_disable_prefetch:
+            # Only apply disable-prefetch for Redis brokers
+            is_redis_broker = c.connection.transport.driver_type == 'redis'
+            if not is_redis_broker:
+                logger.warning(
+                    f"worker_disable_prefetch is only supported for Redis brokers. "
+                    f"Current broker transport: {c.connection.transport.driver_type}. "
+                    f"Ignoring disable_prefetch setting."
+                )
+                return
+
+            from types import MethodType
+
+            from celery.worker import state
+            channel_qos = c.task_consumer.channel.qos
+            original_can_consume = channel_qos.can_consume
+
+            def can_consume(self):
+                # Prefer autoscaler's max_concurrency if set; otherwise fall back to pool size
+                limit = getattr(c.controller, "max_concurrency", None) or c.pool.num_processes
+                if len(state.reserved_requests) >= limit:
+                    return False
+                return original_can_consume()
+
+            channel_qos.can_consume = MethodType(can_consume, channel_qos)
 
     def stop(self, c):
         """Stop task consumer."""
@@ -79,7 +108,9 @@ class Tasks(bootsteps.StartStopStep):
         qos_global = not c.connection.qos_semantics_matches_spec
 
         if c.app.conf.worker_detect_quorum_queues:
-            using_quorum_queues, qname = detect_quorum_queues(c.app, c.connection.transport.driver_type)
+            using_quorum_queues, _ = detect_quorum_queues(
+                c.app, c.connection.transport.driver_type
+            )
 
             if using_quorum_queues:
                 qos_global = False
