@@ -494,6 +494,13 @@ def add_pydantic(data: AddParameterModel) -> AddResultModel:
     return AddResultModel(result=value)
 
 
+@shared_task(pydantic=True)
+def add_pydantic_string_annotations(data: "AddParameterModel") -> "AddResultModel":
+    """Add two numbers, but with string-annotated Pydantic models (__future__.annotations bug)."""
+    value = data.x + data.y
+    return AddResultModel(result=value)
+
+
 if LEGACY_TASKS_DISABLED:
     class StampOnReplace(StampingVisitor):
         stamp = {"StampOnReplace": "This is the replaced task"}
