@@ -9,33 +9,39 @@ from celery.app.control import Control
 
 class WorkerKill:
     """Kills a worker in different ways."""
+
     class Method(Enum):
         DOCKER_KILL = auto()
         CONTROL_SHUTDOWN = auto()
+        SIGTERM = auto()
+        SIGQUIT = auto()
 
     def kill_worker(
         self,
         worker: CeleryTestWorker,
         method: WorkerKill.Method,
-        assertion: bool = True,
     ) -> None:
         """Kill a Celery worker.
 
         Args:
             worker (CeleryTestWorker): Worker to kill.
             method (WorkerKill.Method): The method to kill the worker.
-            assertion (bool, optional): Whether to assert the worker state after kill. Defaults to True.
         """
         if method == WorkerKill.Method.DOCKER_KILL:
             worker.kill()
 
+            assert worker.container.status == "exited", (
+                f"Worker container should be in 'exited' state after kill, "
+                f"but is in '{worker.container.status}' state instead."
+            )
+
         if method == WorkerKill.Method.CONTROL_SHUTDOWN:
             control: Control = worker.app.control
             control.shutdown(destination=[worker.hostname()])
             worker.container.reload()
 
-        if assertion:
-            assert worker.container.status == "exited", (
-                f"Worker container should be in 'exited' state after kill, "
-                f"but is in '{worker.container.status}' state instead."
-            )
+        if method == WorkerKill.Method.SIGTERM:
+            worker.kill(signal="SIGTERM")
+
+        if method == WorkerKill.Method.SIGQUIT:
+            worker.kill(signal="SIGQUIT")
