@@ -1,8 +1,5 @@
-from __future__ import absolute_import, unicode_literals
-
 import operator
-
-from case import Mock
+from unittest.mock import Mock
 
 from celery import signals
 from celery.concurrency import solo
