@@ -56,7 +56,7 @@ class test_Step:
     class Def(bootsteps.StartStopStep):
         name = 'test_Step.Def'
 
-    def setup(self):
+    def setup_method(self):
         self.steps = []
 
     def test_blueprint_name(self, bp='test_blueprint_name'):
@@ -162,7 +162,7 @@ class test_StartStopStep:
     class Def(bootsteps.StartStopStep):
         name = 'test_StartStopStep.Def'
 
-    def setup(self):
+    def setup_method(self):
         self.steps = []
 
     def test_start__stop(self):
